"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from moovio_sdk.models.components import (
    completedmicrodeposits as components_completedmicrodeposits,
    completemicrodeposits as components_completemicrodeposits,
)
from moovio_sdk.types import BaseModel
from moovio_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
import pydantic
from typing import Dict, List
from typing_extensions import Annotated, TypedDict


class CompleteMicroDepositsRequestTypedDict(TypedDict):
    account_id: str
    bank_account_id: str
    complete_micro_deposits: (
        components_completemicrodeposits.CompleteMicroDepositsTypedDict
    )


class CompleteMicroDepositsRequest(BaseModel):
    account_id: Annotated[
        str,
        pydantic.Field(alias="accountID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    bank_account_id: Annotated[
        str,
        pydantic.Field(alias="bankAccountID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    complete_micro_deposits: Annotated[
        components_completemicrodeposits.CompleteMicroDeposits,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]


class CompleteMicroDepositsResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: components_completedmicrodeposits.CompletedMicroDepositsTypedDict


class CompleteMicroDepositsResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: components_completedmicrodeposits.CompletedMicroDeposits
