"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from moovio_sdk.models.components import accountcountries as components_accountcountries
from moovio_sdk.types import BaseModel
from moovio_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
import pydantic
from typing import Dict, List
from typing_extensions import Annotated, TypedDict


class AssignAccountCountriesRequestTypedDict(TypedDict):
    account_id: str
    account_countries: components_accountcountries.AccountCountriesTypedDict


class AssignAccountCountriesRequest(BaseModel):
    account_id: Annotated[
        str,
        pydantic.Field(alias="accountID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    account_countries: Annotated[
        components_accountcountries.AccountCountries,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]


class AssignAccountCountriesResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: components_accountcountries.AccountCountriesTypedDict


class AssignAccountCountriesResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: components_accountcountries.AccountCountries
