"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from moovio_sdk.models.components import (
    imagemetadata as components_imagemetadata,
    imageuploadrequestmultipart as components_imageuploadrequestmultipart,
)
from moovio_sdk.types import BaseModel
from moovio_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
import pydantic
from typing import Dict, List
from typing_extensions import Annotated, TypedDict


class UploadImageRequestTypedDict(TypedDict):
    account_id: str
    image_upload_request_multi_part: (
        components_imageuploadrequestmultipart.ImageUploadRequestMultiPartTypedDict
    )


class UploadImageRequest(BaseModel):
    account_id: Annotated[
        str,
        pydantic.Field(alias="accountID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    image_upload_request_multi_part: Annotated[
        components_imageuploadrequestmultipart.ImageUploadRequestMultiPart,
        FieldMetadata(request=RequestMetadata(media_type="multipart/form-data")),
    ]


class UploadImageResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: components_imagemetadata.ImageMetadataTypedDict


class UploadImageResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: components_imagemetadata.ImageMetadata
