"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from moovio_sdk.models.components import cancellation as components_cancellation
from moovio_sdk.types import BaseModel
from moovio_sdk.utils import FieldMetadata, PathParamMetadata
import pydantic
from typing import Dict, List
from typing_extensions import Annotated, TypedDict


class CreateCancellationRequestTypedDict(TypedDict):
    account_id: str
    r"""The partner's Moov account ID."""
    transfer_id: str
    r"""The transfer ID to cancel."""


class CreateCancellationRequest(BaseModel):
    account_id: Annotated[
        str,
        pydantic.Field(alias="accountID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]
    r"""The partner's Moov account ID."""

    transfer_id: Annotated[
        str,
        pydantic.Field(alias="transferID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]
    r"""The transfer ID to cancel."""


class CreateCancellationResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: components_cancellation.CancellationTypedDict


class CreateCancellationResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: components_cancellation.Cancellation
