"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from moovio_sdk.models.components import updateissuedcard as components_updateissuedcard
from moovio_sdk.types import BaseModel
from moovio_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
import pydantic
from typing import Dict, List
from typing_extensions import Annotated, TypedDict


class UpdateIssuedCardRequestTypedDict(TypedDict):
    account_id: str
    r"""The Moov business account for which the card was issued."""
    issued_card_id: str
    update_issued_card: components_updateissuedcard.UpdateIssuedCardTypedDict


class UpdateIssuedCardRequest(BaseModel):
    account_id: Annotated[
        str,
        pydantic.Field(alias="accountID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]
    r"""The Moov business account for which the card was issued."""

    issued_card_id: Annotated[
        str,
        pydantic.Field(alias="issuedCardID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    update_issued_card: Annotated[
        components_updateissuedcard.UpdateIssuedCard,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]


class UpdateIssuedCardResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]


class UpdateIssuedCardResponse(BaseModel):
    headers: Dict[str, List[str]]
