"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .address import Address, AddressTypedDict
from .wireservices import WireServices, WireServicesTypedDict
from moovio_sdk.types import BaseModel, UNSET_SENTINEL
import pydantic
from pydantic import model_serializer
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class WireInstitutionTypedDict(TypedDict):
    name: str
    r"""Name of the financial institution."""
    routing_number: str
    services: WireServicesTypedDict
    address: NotRequired[AddressTypedDict]


class WireInstitution(BaseModel):
    name: str
    r"""Name of the financial institution."""

    routing_number: Annotated[str, pydantic.Field(alias="routingNumber")]

    services: WireServices

    address: Optional[Address] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["address"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


try:
    WireInstitution.model_rebuild()
except NameError:
    pass
