"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from moovio_sdk.models.components import (
    terminalapplication as components_terminalapplication,
)
from moovio_sdk.types import BaseModel
from moovio_sdk.utils import FieldMetadata, PathParamMetadata
import pydantic
from typing import Dict, List
from typing_extensions import Annotated, TypedDict


class GetTerminalApplicationRequestTypedDict(TypedDict):
    terminal_application_id: str


class GetTerminalApplicationRequest(BaseModel):
    terminal_application_id: Annotated[
        str,
        pydantic.Field(alias="terminalApplicationID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]


class GetTerminalApplicationResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: components_terminalapplication.TerminalApplicationTypedDict


class GetTerminalApplicationResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: components_terminalapplication.TerminalApplication
