"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from moovio_sdk.models.components import sweep as components_sweep
from moovio_sdk.types import BaseModel
from moovio_sdk.utils import FieldMetadata, PathParamMetadata
import pydantic
from typing import Dict, List
from typing_extensions import Annotated, TypedDict


class GetSweepRequestTypedDict(TypedDict):
    account_id: str
    wallet_id: str
    sweep_id: str


class GetSweepRequest(BaseModel):
    account_id: Annotated[
        str,
        pydantic.Field(alias="accountID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    wallet_id: Annotated[
        str,
        pydantic.Field(alias="walletID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    sweep_id: Annotated[
        str,
        pydantic.Field(alias="sweepID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]


class GetSweepResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: components_sweep.SweepTypedDict


class GetSweepResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: components_sweep.Sweep
