"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from moovio_sdk.models.components import eventtype as components_eventtype
from moovio_sdk.types import BaseModel
from typing import Dict, List
from typing_extensions import TypedDict


class ListEventTypesResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: List[components_eventtype.EventTypeTypedDict]


class ListEventTypesResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: List[components_eventtype.EventType]
