"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from moovio_sdk.types import BaseModel
from moovio_sdk.utils import FieldMetadata, PathParamMetadata
import pydantic
from typing import Dict, List
from typing_extensions import Annotated, TypedDict


class DeleteDisputeEvidenceFileRequestTypedDict(TypedDict):
    account_id: str
    dispute_id: str
    evidence_id: str


class DeleteDisputeEvidenceFileRequest(BaseModel):
    account_id: Annotated[
        str,
        pydantic.Field(alias="accountID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    dispute_id: Annotated[
        str,
        pydantic.Field(alias="disputeID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    evidence_id: Annotated[
        str,
        pydantic.Field(alias="evidenceID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]


class DeleteDisputeEvidenceFileResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]


class DeleteDisputeEvidenceFileResponse(BaseModel):
    headers: Dict[str, List[str]]
