"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .createpaymentlinklineitem import (
    CreatePaymentLinkLineItem,
    CreatePaymentLinkLineItemTypedDict,
)
from moovio_sdk.types import BaseModel, UNSET_SENTINEL
from pydantic import model_serializer
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class CreatePaymentLinkLineItemsUpdateTypedDict(TypedDict):
    r"""An optional collection of line items for a payment link.
    When line items are provided, their total plus sales tax must equal the payment link amount.
    """

    items: NotRequired[List[CreatePaymentLinkLineItemTypedDict]]
    r"""The list of line items."""


class CreatePaymentLinkLineItemsUpdate(BaseModel):
    r"""An optional collection of line items for a payment link.
    When line items are provided, their total plus sales tax must equal the payment link amount.
    """

    items: Optional[List[CreatePaymentLinkLineItem]] = None
    r"""The list of line items."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["items"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m
