"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from moovio_sdk.types import BaseModel
import pydantic
from typing_extensions import Annotated, TypedDict


class WebhookDataPaymentMethodEnabledTypedDict(TypedDict):
    account_id: str
    payment_method_id: str
    source_id: str


class WebhookDataPaymentMethodEnabled(BaseModel):
    account_id: Annotated[str, pydantic.Field(alias="accountID")]

    payment_method_id: Annotated[str, pydantic.Field(alias="paymentMethodID")]

    source_id: Annotated[str, pydantic.Field(alias="sourceID")]


try:
    WebhookDataPaymentMethodEnabled.model_rebuild()
except NameError:
    pass
