"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
import httpx
from moovio_sdk.models.components import qrcode as components_qrcode
from moovio_sdk.types import BaseModel
from moovio_sdk.utils import FieldMetadata, PathParamMetadata
import pydantic
from typing import Dict, List, Union
from typing_extensions import Annotated, TypeAliasType, TypedDict


class GetPaymentLinkQRCodeRequestTypedDict(TypedDict):
    account_id: str
    r"""The merchant account ID."""
    payment_link_code: str


class GetPaymentLinkQRCodeRequest(BaseModel):
    account_id: Annotated[
        str,
        pydantic.Field(alias="accountID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]
    r"""The merchant account ID."""

    payment_link_code: Annotated[
        str,
        pydantic.Field(alias="paymentLinkCode"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]


GetPaymentLinkQRCodeResponseResultTypedDict = TypeAliasType(
    "GetPaymentLinkQRCodeResponseResultTypedDict",
    Union[components_qrcode.QRCodeTypedDict, httpx.Response],
)


GetPaymentLinkQRCodeResponseResult = TypeAliasType(
    "GetPaymentLinkQRCodeResponseResult",
    Union[components_qrcode.QRCode, httpx.Response],
)


class GetPaymentLinkQRCodeResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: GetPaymentLinkQRCodeResponseResultTypedDict


class GetPaymentLinkQRCodeResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: GetPaymentLinkQRCodeResponseResult
