"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from moovio_sdk.models.components import (
    scheduleresponse as components_scheduleresponse,
    upsertschedule as components_upsertschedule,
)
from moovio_sdk.types import BaseModel
from moovio_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
import pydantic
from typing import Dict, List
from typing_extensions import Annotated, TypedDict


class UpdateScheduleRequestTypedDict(TypedDict):
    account_id: str
    r"""Account ID of the account that will run the transfer."""
    schedule_id: str
    upsert_schedule: components_upsertschedule.UpsertScheduleTypedDict


class UpdateScheduleRequest(BaseModel):
    account_id: Annotated[
        str,
        pydantic.Field(alias="accountID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]
    r"""Account ID of the account that will run the transfer."""

    schedule_id: Annotated[
        str,
        pydantic.Field(alias="scheduleID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    upsert_schedule: Annotated[
        components_upsertschedule.UpsertSchedule,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]


class UpdateScheduleResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: components_scheduleresponse.ScheduleResponseTypedDict


class UpdateScheduleResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: components_scheduleresponse.ScheduleResponse
