"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from moovio_sdk.types import BaseModel
from moovio_sdk.utils import FieldMetadata, PathParamMetadata
from typing import Dict, List
from typing_extensions import Annotated, TypedDict


class RevokeOnboardingInviteRequestTypedDict(TypedDict):
    code: str


class RevokeOnboardingInviteRequest(BaseModel):
    code: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]


class RevokeOnboardingInviteResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]


class RevokeOnboardingInviteResponse(BaseModel):
    headers: Dict[str, List[str]]
