"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from moovio_sdk.models.components import (
    createinvoicepayment as components_createinvoicepayment,
    invoicepayment as components_invoicepayment,
)
from moovio_sdk.types import BaseModel
from moovio_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
import pydantic
from typing import Dict, List
from typing_extensions import Annotated, TypedDict


class CreateInvoicePaymentRequestTypedDict(TypedDict):
    account_id: str
    invoice_id: str
    create_invoice_payment: (
        components_createinvoicepayment.CreateInvoicePaymentTypedDict
    )


class CreateInvoicePaymentRequest(BaseModel):
    account_id: Annotated[
        str,
        pydantic.Field(alias="accountID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    invoice_id: Annotated[
        str,
        pydantic.Field(alias="invoiceID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    create_invoice_payment: Annotated[
        components_createinvoicepayment.CreateInvoicePayment,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]


class CreateInvoicePaymentResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: components_invoicepayment.InvoicePaymentTypedDict


class CreateInvoicePaymentResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: components_invoicepayment.InvoicePayment
