"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .resolutionlinkrecipient import (
    ResolutionLinkRecipient,
    ResolutionLinkRecipientTypedDict,
)
from moovio_sdk.types import BaseModel
from typing_extensions import TypedDict


class CreateResolutionLinkTypedDict(TypedDict):
    r"""Request body for creating a resolution link."""

    recipient: ResolutionLinkRecipientTypedDict
    r"""The recipient contact information for the resolution link."""


class CreateResolutionLink(BaseModel):
    r"""Request body for creating a resolution link."""

    recipient: ResolutionLinkRecipient
    r"""The recipient contact information for the resolution link."""
