"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .phonenumber import PhoneNumber, PhoneNumberTypedDict
from moovio_sdk.types import BaseModel, UNSET_SENTINEL
from pydantic import model_serializer
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class ResolutionLinkRecipientTypedDict(TypedDict):
    r"""Contact information for the recipient of a resolution link. Provide either `email` or `phone`, but not both."""

    email: NotRequired[str]
    r"""The email address of the recipient."""
    phone: NotRequired[PhoneNumberTypedDict]
    r"""The phone number of the recipient."""


class ResolutionLinkRecipient(BaseModel):
    r"""Contact information for the recipient of a resolution link. Provide either `email` or `phone`, but not both."""

    email: Optional[str] = None
    r"""The email address of the recipient."""

    phone: Optional[PhoneNumber] = None
    r"""The phone number of the recipient."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["email", "phone"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m
