"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from moovio_sdk.models.components import (
    paymentlink as components_paymentlink,
    updatepaymentlink as components_updatepaymentlink,
)
from moovio_sdk.types import BaseModel
from moovio_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
import pydantic
from typing import Dict, List
from typing_extensions import Annotated, TypedDict


class UpdatePaymentLinkRequestTypedDict(TypedDict):
    account_id: str
    r"""The merchant account ID."""
    payment_link_code: str
    update_payment_link: components_updatepaymentlink.UpdatePaymentLinkTypedDict


class UpdatePaymentLinkRequest(BaseModel):
    account_id: Annotated[
        str,
        pydantic.Field(alias="accountID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]
    r"""The merchant account ID."""

    payment_link_code: Annotated[
        str,
        pydantic.Field(alias="paymentLinkCode"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    update_payment_link: Annotated[
        components_updatepaymentlink.UpdatePaymentLink,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]


class UpdatePaymentLinkResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: components_paymentlink.PaymentLinkTypedDict


class UpdatePaymentLinkResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: components_paymentlink.PaymentLink
