"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from moovio_sdk.models.components import authtoken as components_authtoken
from moovio_sdk.types import BaseModel
from typing import Dict, List
from typing_extensions import TypedDict


class CreateAccessTokenResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: components_authtoken.AuthTokenTypedDict


class CreateAccessTokenResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: components_authtoken.AuthToken
