"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

import importlib.metadata

__title__: str = "moovio_sdk"
__version__: str = "26.4.0-dev.15"
__openapi_doc_version__: str = "v2026.04.00"
__gen_version__: str = "2.865.2"
__user_agent__: str = (
    "speakeasy-sdk/python 26.4.0-dev.15 2.865.2 v2026.04.00 moovio_sdk"
)

try:
    if __package__ is not None:
        __version__ = importlib.metadata.version(__package__)
except importlib.metadata.PackageNotFoundError:
    pass
