"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from moovio_sdk.models.components import (
    accountterminalapplication as components_accountterminalapplication,
    linkaccountterminalapplication as components_linkaccountterminalapplication,
)
from moovio_sdk.types import BaseModel
from moovio_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
import pydantic
from typing import Dict, List
from typing_extensions import Annotated, TypedDict


class LinkAccountTerminalApplicationRequestTypedDict(TypedDict):
    account_id: str
    link_account_terminal_application: components_linkaccountterminalapplication.LinkAccountTerminalApplicationTypedDict


class LinkAccountTerminalApplicationRequest(BaseModel):
    account_id: Annotated[
        str,
        pydantic.Field(alias="accountID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    link_account_terminal_application: Annotated[
        components_linkaccountterminalapplication.LinkAccountTerminalApplication,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]


class LinkAccountTerminalApplicationResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: components_accountterminalapplication.AccountTerminalApplicationTypedDict


class LinkAccountTerminalApplicationResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: components_accountterminalapplication.AccountTerminalApplication
