"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from moovio_sdk.models.components import (
    issuedcardauthorization as components_issuedcardauthorization,
)
from moovio_sdk.types import BaseModel
from moovio_sdk.utils import FieldMetadata, PathParamMetadata
import pydantic
from typing import Dict, List
from typing_extensions import Annotated, TypedDict


class GetIssuedCardAuthorizationRequestTypedDict(TypedDict):
    account_id: str
    r"""The Moov business account for which cards have been issued."""
    authorization_id: str


class GetIssuedCardAuthorizationRequest(BaseModel):
    account_id: Annotated[
        str,
        pydantic.Field(alias="accountID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]
    r"""The Moov business account for which cards have been issued."""

    authorization_id: Annotated[
        str,
        pydantic.Field(alias="authorizationID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]


class GetIssuedCardAuthorizationResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: components_issuedcardauthorization.IssuedCardAuthorizationTypedDict


class GetIssuedCardAuthorizationResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: components_issuedcardauthorization.IssuedCardAuthorization
