"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from moovio_sdk.models.components import (
    cardacquiringrefund as components_cardacquiringrefund,
)
from moovio_sdk.types import BaseModel
from moovio_sdk.utils import FieldMetadata, PathParamMetadata
import pydantic
from typing import Dict, List
from typing_extensions import Annotated, TypedDict


class GetRefundRequestTypedDict(TypedDict):
    transfer_id: str
    r"""Identifier for the transfer."""
    account_id: str
    refund_id: str
    r"""Identifier for the refund."""


class GetRefundRequest(BaseModel):
    transfer_id: Annotated[
        str,
        pydantic.Field(alias="transferID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]
    r"""Identifier for the transfer."""

    account_id: Annotated[
        str,
        pydantic.Field(alias="accountID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    refund_id: Annotated[
        str,
        pydantic.Field(alias="refundID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]
    r"""Identifier for the refund."""


class GetRefundResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: components_cardacquiringrefund.CardAcquiringRefundTypedDict


class GetRefundResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: components_cardacquiringrefund.CardAcquiringRefund
