"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from moovio_sdk.types import BaseModel
from typing import Dict, List
from typing_extensions import TypedDict


class TestEndToEndTokenResponseTypedDict(TypedDict):
    __test__ = False  # pyright: ignore[reportGeneralTypeIssues]

    headers: Dict[str, List[str]]


class TestEndToEndTokenResponse(BaseModel):
    __test__ = False

    headers: Dict[str, List[str]]
