"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from moovio_sdk.models.components import (
    createtransferoptions as components_createtransferoptions,
    transferoptions as components_transferoptions,
)
from moovio_sdk.types import BaseModel
from moovio_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
import pydantic
from typing import Dict, List
from typing_extensions import Annotated, TypedDict


class CreateTransferOptionsRequestTypedDict(TypedDict):
    account_id: str
    r"""The partner's Moov account ID."""
    create_transfer_options: (
        components_createtransferoptions.CreateTransferOptionsTypedDict
    )


class CreateTransferOptionsRequest(BaseModel):
    account_id: Annotated[
        str,
        pydantic.Field(alias="accountID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]
    r"""The partner's Moov account ID."""

    create_transfer_options: Annotated[
        components_createtransferoptions.CreateTransferOptions,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]


class CreateTransferOptionsResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: components_transferoptions.TransferOptionsTypedDict


class CreateTransferOptionsResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: components_transferoptions.TransferOptions
