"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from moovio_sdk.models.components import (
    createwallet as components_createwallet,
    wallet as components_wallet,
)
from moovio_sdk.types import BaseModel
from moovio_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
import pydantic
from typing import Dict, List
from typing_extensions import Annotated, TypedDict


class CreateWalletRequestTypedDict(TypedDict):
    account_id: str
    r"""The Moov account ID the wallet belongs to."""
    create_wallet: components_createwallet.CreateWalletTypedDict


class CreateWalletRequest(BaseModel):
    account_id: Annotated[
        str,
        pydantic.Field(alias="accountID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]
    r"""The Moov account ID the wallet belongs to."""

    create_wallet: Annotated[
        components_createwallet.CreateWallet,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]


class CreateWalletResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: components_wallet.WalletTypedDict


class CreateWalletResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: components_wallet.Wallet
