"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from moovio_sdk.models.components import paymentmethod as components_paymentmethod
from moovio_sdk.types import BaseModel
from moovio_sdk.utils import FieldMetadata, PathParamMetadata
import pydantic
from typing import Dict, List
from typing_extensions import Annotated, TypedDict


class GetPaymentMethodRequestTypedDict(TypedDict):
    account_id: str
    payment_method_id: str


class GetPaymentMethodRequest(BaseModel):
    account_id: Annotated[
        str,
        pydantic.Field(alias="accountID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    payment_method_id: Annotated[
        str,
        pydantic.Field(alias="paymentMethodID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]


class GetPaymentMethodResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: components_paymentmethod.PaymentMethodTypedDict


class GetPaymentMethodResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: components_paymentmethod.PaymentMethod
