"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from moovio_sdk.models.components import (
    enrichedbusinessresponse as components_enrichedbusinessresponse,
)
from moovio_sdk.types import BaseModel
from moovio_sdk.utils import FieldMetadata, QueryParamMetadata
from typing import Dict, List
from typing_extensions import Annotated, TypedDict


class GetEnrichmentProfileRequestTypedDict(TypedDict):
    email: str


class GetEnrichmentProfileRequest(BaseModel):
    email: Annotated[
        str, FieldMetadata(query=QueryParamMetadata(style="form", explode=False))
    ]


class GetEnrichmentProfileResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: components_enrichedbusinessresponse.EnrichedBusinessResponseTypedDict


class GetEnrichmentProfileResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: components_enrichedbusinessresponse.EnrichedBusinessResponse
