"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from moovio_sdk.models.components import (
    issuedcard as components_issuedcard,
    requestcard as components_requestcard,
)
from moovio_sdk.types import BaseModel
from moovio_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
import pydantic
from typing import Dict, List
from typing_extensions import Annotated, TypedDict


class RequestCardRequestTypedDict(TypedDict):
    account_id: str
    r"""The Moov business account for which the card is to be issued."""
    request_card: components_requestcard.RequestCardTypedDict


class RequestCardRequest(BaseModel):
    account_id: Annotated[
        str,
        pydantic.Field(alias="accountID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]
    r"""The Moov business account for which the card is to be issued."""

    request_card: Annotated[
        components_requestcard.RequestCard,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]


class RequestCardResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: components_issuedcard.IssuedCardTypedDict


class RequestCardResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: components_issuedcard.IssuedCard
