"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from dataclasses import dataclass, field
import httpx
from moovio_sdk.models.errors import MoovError
from moovio_sdk.types import BaseModel
import pydantic
from typing import Dict, Optional
from typing_extensions import Annotated


class ConnectAccountRequestValidationErrorData(BaseModel):
    principal_account_id: Annotated[
        Optional[str], pydantic.Field(alias="principalAccountID")
    ] = None
    allow_scopes: Annotated[
        Optional[Dict[str, str]], pydantic.Field(alias="allowScopes")
    ] = None


@dataclass(unsafe_hash=True)
class ConnectAccountRequestValidationError(MoovError):
    data: ConnectAccountRequestValidationErrorData = field(hash=False)

    def __init__(
        self,
        data: ConnectAccountRequestValidationErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        message = body or raw_response.text
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)
