"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from moovio_sdk.models.components import (
    ticket as components_ticket,
    updateticket as components_updateticket,
)
from moovio_sdk.types import BaseModel
from moovio_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
import pydantic
from typing import Dict, List
from typing_extensions import Annotated, TypedDict


class UpdateTicketRequestTypedDict(TypedDict):
    account_id: str
    ticket_id: str
    update_ticket: components_updateticket.UpdateTicketTypedDict


class UpdateTicketRequest(BaseModel):
    account_id: Annotated[
        str,
        pydantic.Field(alias="accountID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    ticket_id: Annotated[
        str,
        pydantic.Field(alias="ticketID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    update_ticket: Annotated[
        components_updateticket.UpdateTicket,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]


class UpdateTicketResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: components_ticket.TicketTypedDict


class UpdateTicketResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: components_ticket.Ticket
