"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from moovio_sdk.models.components import (
    product as components_product,
    productrequest as components_productrequest,
)
from moovio_sdk.types import BaseModel
from moovio_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
import pydantic
from typing import Dict, List
from typing_extensions import Annotated, TypedDict


class CreateProductRequestTypedDict(TypedDict):
    account_id: str
    product_request: components_productrequest.ProductRequestTypedDict


class CreateProductRequest(BaseModel):
    account_id: Annotated[
        str,
        pydantic.Field(alias="accountID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    product_request: Annotated[
        components_productrequest.ProductRequest,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]


class CreateProductResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: components_product.ProductTypedDict


class CreateProductResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: components_product.Product
