"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from moovio_sdk.models.components import (
    bankaccountverification as components_bankaccountverification,
    completebankaccountverification as components_completebankaccountverification,
)
from moovio_sdk.types import BaseModel
from moovio_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
import pydantic
from typing import Dict, List
from typing_extensions import Annotated, TypedDict


class CompleteBankAccountVerificationRequestTypedDict(TypedDict):
    account_id: str
    bank_account_id: str
    complete_bank_account_verification: components_completebankaccountverification.CompleteBankAccountVerificationTypedDict


class CompleteBankAccountVerificationRequest(BaseModel):
    account_id: Annotated[
        str,
        pydantic.Field(alias="accountID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    bank_account_id: Annotated[
        str,
        pydantic.Field(alias="bankAccountID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    complete_bank_account_verification: Annotated[
        components_completebankaccountverification.CompleteBankAccountVerification,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]


class CompleteBankAccountVerificationResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: components_bankaccountverification.BankAccountVerificationTypedDict


class CompleteBankAccountVerificationResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: components_bankaccountverification.BankAccountVerification
