"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from moovio_sdk.models.components import (
    terminalapplicationversion as components_terminalapplicationversion,
)
from moovio_sdk.types import BaseModel
from moovio_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
import pydantic
from typing import Dict, List
from typing_extensions import Annotated, TypedDict


class CreateTerminalApplicationVersionRequestTypedDict(TypedDict):
    terminal_application_id: str
    terminal_application_version: (
        components_terminalapplicationversion.TerminalApplicationVersionTypedDict
    )


class CreateTerminalApplicationVersionRequest(BaseModel):
    terminal_application_id: Annotated[
        str,
        pydantic.Field(alias="terminalApplicationID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    terminal_application_version: Annotated[
        components_terminalapplicationversion.TerminalApplicationVersion,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]


class CreateTerminalApplicationVersionResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: components_terminalapplicationversion.TerminalApplicationVersionTypedDict


class CreateTerminalApplicationVersionResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: components_terminalapplicationversion.TerminalApplicationVersion
