"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from moovio_sdk.models.components import (
    updateapplepaymerchantdomains as components_updateapplepaymerchantdomains,
)
from moovio_sdk.types import BaseModel
from moovio_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
import pydantic
from typing import Dict, List
from typing_extensions import Annotated, TypedDict


class UpdateApplePayMerchantDomainsRequestTypedDict(TypedDict):
    account_id: str
    r"""ID of the Moov account representing the merchant."""
    update_apple_pay_merchant_domains: (
        components_updateapplepaymerchantdomains.UpdateApplePayMerchantDomainsTypedDict
    )


class UpdateApplePayMerchantDomainsRequest(BaseModel):
    account_id: Annotated[
        str,
        pydantic.Field(alias="accountID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]
    r"""ID of the Moov account representing the merchant."""

    update_apple_pay_merchant_domains: Annotated[
        components_updateapplepaymerchantdomains.UpdateApplePayMerchantDomains,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]


class UpdateApplePayMerchantDomainsResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]


class UpdateApplePayMerchantDomainsResponse(BaseModel):
    headers: Dict[str, List[str]]
