"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from moovio_sdk.models.components import (
    createevidencefilemultipart as components_createevidencefilemultipart,
    evidenceuploadresponse as components_evidenceuploadresponse,
)
from moovio_sdk.types import BaseModel
from moovio_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
import pydantic
from typing import Dict, List
from typing_extensions import Annotated, TypedDict


class UploadDisputeEvidenceFileRequestTypedDict(TypedDict):
    account_id: str
    dispute_id: str
    create_evidence_file_multi_part: (
        components_createevidencefilemultipart.CreateEvidenceFileMultiPartTypedDict
    )


class UploadDisputeEvidenceFileRequest(BaseModel):
    account_id: Annotated[
        str,
        pydantic.Field(alias="accountID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    dispute_id: Annotated[
        str,
        pydantic.Field(alias="disputeID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    create_evidence_file_multi_part: Annotated[
        components_createevidencefilemultipart.CreateEvidenceFileMultiPart,
        FieldMetadata(request=RequestMetadata(media_type="multipart/form-data")),
    ]


class UploadDisputeEvidenceFileResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: components_evidenceuploadresponse.EvidenceUploadResponseTypedDict


class UploadDisputeEvidenceFileResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: components_evidenceuploadresponse.EvidenceUploadResponse
