"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from moovio_sdk.models.components import (
    underwriting as components_underwriting,
    upsertunderwriting as components_upsertunderwriting,
)
from moovio_sdk.types import BaseModel
from moovio_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
import pydantic
from typing import Dict, List
from typing_extensions import Annotated, TypedDict


class SaveUnderwritingRequestTypedDict(TypedDict):
    account_id: str
    upsert_underwriting: components_upsertunderwriting.UpsertUnderwritingTypedDict


class SaveUnderwritingRequest(BaseModel):
    account_id: Annotated[
        str,
        pydantic.Field(alias="accountID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    upsert_underwriting: Annotated[
        components_upsertunderwriting.UpsertUnderwriting,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]


class SaveUnderwritingResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: components_underwriting.UnderwritingTypedDict


class SaveUnderwritingResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: components_underwriting.Underwriting
