"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from moovio_sdk.models.components import sweepconfig as components_sweepconfig
from moovio_sdk.types import BaseModel
from moovio_sdk.utils import FieldMetadata, PathParamMetadata
import pydantic
from typing import Dict, List
from typing_extensions import Annotated, TypedDict


class GetSweepConfigRequestTypedDict(TypedDict):
    account_id: str
    sweep_config_id: str


class GetSweepConfigRequest(BaseModel):
    account_id: Annotated[
        str,
        pydantic.Field(alias="accountID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    sweep_config_id: Annotated[
        str,
        pydantic.Field(alias="sweepConfigID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]


class GetSweepConfigResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: components_sweepconfig.SweepConfigTypedDict


class GetSweepConfigResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: components_sweepconfig.SweepConfig
