"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from moovio_sdk.models.components import webhooksecret as components_webhooksecret
from moovio_sdk.types import BaseModel
from moovio_sdk.utils import FieldMetadata, PathParamMetadata
import pydantic
from typing import Dict, List
from typing_extensions import Annotated, TypedDict


class GetWebhookSecretRequestTypedDict(TypedDict):
    webhook_id: str


class GetWebhookSecretRequest(BaseModel):
    webhook_id: Annotated[
        str,
        pydantic.Field(alias="webhookID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]


class GetWebhookSecretResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: components_webhooksecret.WebhookSecretTypedDict


class GetWebhookSecretResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: components_webhooksecret.WebhookSecret
