"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from moovio_sdk.models.components import cancellation as components_cancellation
from moovio_sdk.types import BaseModel
from moovio_sdk.utils import FieldMetadata, PathParamMetadata
import pydantic
from typing import Dict, List
from typing_extensions import Annotated, TypedDict


class GetCancellationRequestTypedDict(TypedDict):
    account_id: str
    r"""Moov account ID of the partner or transfer's source or destination."""
    transfer_id: str
    r"""Identifier for the transfer."""
    cancellation_id: str
    r"""Identifier for the cancellation."""


class GetCancellationRequest(BaseModel):
    account_id: Annotated[
        str,
        pydantic.Field(alias="accountID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]
    r"""Moov account ID of the partner or transfer's source or destination."""

    transfer_id: Annotated[
        str,
        pydantic.Field(alias="transferID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]
    r"""Identifier for the transfer."""

    cancellation_id: Annotated[
        str,
        pydantic.Field(alias="cancellationID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]
    r"""Identifier for the cancellation."""


class GetCancellationResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: components_cancellation.CancellationTypedDict


class GetCancellationResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: components_cancellation.Cancellation
