"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from moovio_sdk.models.components import (
    patchtransfer as components_patchtransfer,
    transfer as components_transfer,
)
from moovio_sdk.types import BaseModel
from moovio_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
import pydantic
from typing import Dict, List
from typing_extensions import Annotated, TypedDict


class UpdateTransferRequestTypedDict(TypedDict):
    transfer_id: str
    r"""Identifier for the transfer."""
    account_id: str
    patch_transfer: components_patchtransfer.PatchTransferTypedDict


class UpdateTransferRequest(BaseModel):
    transfer_id: Annotated[
        str,
        pydantic.Field(alias="transferID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]
    r"""Identifier for the transfer."""

    account_id: Annotated[
        str,
        pydantic.Field(alias="accountID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    patch_transfer: Annotated[
        components_patchtransfer.PatchTransfer,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]


class UpdateTransferResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: components_transfer.TransferTypedDict


class UpdateTransferResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: components_transfer.Transfer
