"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .patchbusiness import PatchBusiness, PatchBusinessTypedDict
from .patchindividual import PatchIndividual, PatchIndividualTypedDict
from moovio_sdk.types import BaseModel, UNSET_SENTINEL
from pydantic import model_serializer
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class PatchProfileTypedDict(TypedDict):
    r"""Describes the fields available when patching a profile.
    Each object can be patched independent of patching the other fields.
    """

    individual: NotRequired[PatchIndividualTypedDict]
    r"""Describes the fields available when patching an individual."""
    business: NotRequired[PatchBusinessTypedDict]


class PatchProfile(BaseModel):
    r"""Describes the fields available when patching a profile.
    Each object can be patched independent of patching the other fields.
    """

    individual: Optional[PatchIndividual] = None
    r"""Describes the fields available when patching an individual."""

    business: Optional[PatchBusiness] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["individual", "business"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m
